@@ -45,8 +45,8 @@ require 'aprs4r/LogPluginConfiguration'
 
 class APRS4RConfiguration
 
-  attr_reader :devices, :beacons, :gateways, :digipeaters, :plugins
-  attr_writer :devices, :beacons, :gateways, :digipeaters, :plugins
+  attr_reader :devices, :plugins
+  attr_writer :devices, :plugins
 
   @@logger = Logger.get_logger( "APRS4RConfiguration")
 
@@ -55,10 +55,7 @@ class APRS4RConfiguration
     @@logger.info( "initialize()")
 
     @devices = Hash.new
-
-    @beacons = Hash.new
-    @gateways = Hash.new
-    @digipeaters = Hash.new
+    @plugins = Hash.new
 
     return
   end
@@ -94,12 +91,14 @@ class APRS4RConfiguration
 
     YAML.dump( configuration, file)
 
+    file.close
+
     return
   end
 
 
   def to_yaml_properties
-    %w{@devices @beacons @gateways @digipeaters @plugins}
+    %w{@devices @plugins}
   end
 
 end
