@@ -18,6 +18,7 @@
 #
 
 require 'aprs4r/SocketConfiguration'
+require 'aprs4r/ConfigurationAttribute'
 
 
 class AX25SocketConfiguration < SocketConfiguration
@@ -27,7 +28,21 @@ class AX25SocketConfiguration < SocketConfiguration
 
 
   def to_yaml_properties
-    %w{ @device @baudrate @mode @call @speed}
+    super + %w{@device @baudrate @mode @call @speed}
+  end
+
+
+  def attributes
+    attributes = [
+                  ConfigurationAttribute.new( "device", true, 10, "string", "Ger&auml;t", 10),
+                  ConfigurationAttribute.new( "baudrate", true, 11, "int", "Baudrate", 6),
+                  ConfigurationAttribute.new( "mode", true, 12, "string", "Modus", 20),
+                  ConfigurationAttribute.new( "call", true, 13, "string", "Rufzeichen", 10),
+                  ConfigurationAttribute.new( "speed", true, 14, "int", "Geschwindigkeit", 6),
+                  ConfigurationAttribute.new( "timeout", true, 15, "int", "Timeout", 6)
+                 ]
+
+    return super + attributes
   end
 
 end
