@@ -17,9 +17,11 @@
 #  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 #
 
+require 'aprs4r/ConfigurationAttribute'
 require 'aprs4r/PluginConfiguration'
 
 require 'aprs4r/APRSCall'
+require 'aprs4r/APRSMessage'
 
 
 class BeaconPluginConfiguration < PluginConfiguration
@@ -29,7 +31,20 @@ class BeaconPluginConfiguration < PluginConfiguration
 
 
   def to_yaml_properties
-    %w{ super @device @period @offset @message}
+    return super + %w{ @device @period @offset @message}
+  end
+
+  
+  def attributes
+    
+    attributes = [ 
+                  ConfigurationAttribute.new( "device", 11, "text", "Name", 10), 
+                  ConfigurationAttribute.new( "period", 12, "int", "Periode", 10),
+                  ConfigurationAttribute.new( "offset", 13, "int", "Offset", 0),
+                  ConfigurationAttribute.new( "message", 14, "complex", "Bake", 10, APRSMessage.attributes)
+                 ]
+
+    return super + attributes
   end
 
 end
