@@ -20,17 +20,19 @@
 
 class ConfigurationAttribute
 	
-  attr_reader :name, :order, :type, :quantity, :description, :length
+  attr_reader :name, :mutable, :order, :type, :description, :length, :extension
   
   
-  def initialize( name, order, type, quantity, description, length)
+  def initialize( name, mutable, order, type, description, length, extension = nil)
     
     @name = name
+    @mutable = mutable
     @order = order
     @type = type
-    @quantity = quantity
     @description = description
     @length = length
+
+    @extension = extension
     
     return
   end
