@@ -50,7 +50,13 @@ class DigipeaterPlugin < Plugin
       }
     end
 
-    @hops = configuration.hops
+    @rfonly = false
+    @rfonly = configuration.rfonly if configuration.rfonly == true
+
+    @reducePath = false
+    @reducePath = configuration.reducePath if configuration.reducePath == true
+    
+    @permittedHops = configuration.permittedHops
 
     return
   end
@@ -118,25 +124,32 @@ class DigipeaterPlugin < Plugin
       return
     end
 
-    @@logger.debug( "do_digipeating: message: #{message}")
+    if message.path.nil? || message.path.empty?
+      @@logger.warn( "no path")
+      return
+    end
+
+    # translate path
     message = translate_path( message)
-    @@logger.debug( "do_digipeating: after translate: #{message}")
+    @@logger.debug( "do_digipeating: path translate: #{message}")
+
+    # optimize path 
+    message = optimize_path( message)
+    @@logger.debug( "do_digipeating: path optimize: #{message}")
 
     path = message.path
 
-    rfonly = false
-    if path 
+    # reduce path (if enabled)
+    if @reducePath
+      rfonly = false
       path.each{ |entry|
         rfonly = true if entry == @@RFONLY
       }
-    end
-    
-    if !rfonly 
-      message = optimize_path( message)
-      @@logger.debug( "do_digipeating: after optimize: #{message}")
-      
-      message = reduce_path( message)
-      @@logger.debug( "do_digipeating: after reduce: #{message}")
+
+      if (@rfonly == false) || ((@rfonly == true) && (rfonly == false))
+        message = reduce_path( message)
+        @@logger.debug( "do_digipeating: path reduce: #{message}")
+      end
     end
 
     path = message.path
@@ -178,7 +191,7 @@ class DigipeaterPlugin < Plugin
         end
 
         path[i] = entry.to_s
-        path.insert( i, digi)
+        path.insert( i, digi.to_s)
 
         message.path = path
 
@@ -321,14 +334,18 @@ class DigipeaterPlugin < Plugin
         if last_wide_ssid + current_ssid <= 7
           last_wide_ssid += current_ssid
         else 
-          path_new << "WIDE" + last_wide_ssid.to_s + "-" + last_wide_ssid.to_s
+          wide_new = "WIDE" + last_wide_ssid.to_s + "-" + last_wide_ssid.to_s
+          wide_new = "WIDE2-1" if wide_new == "WIDE1-1"
+          path_new << wide_new
           last_wide_ssid = current_ssid
         end
       elsif call.call =~ /TRACE[2-9]/ && call.ssid > 0
         if last_trace_ssid + current_ssid <= 7
           last_trace_ssid += current_ssid
         else 
-          path_new << "TRACE" + last_trace_ssid.to_s + "-" + last_trace_ssid.to_s
+          trace_new = "TRACE" + last_trace_ssid.to_s + "-" + last_trace_ssid.to_s
+          trace_new = "TRACE2-1" if trace_new == "TRACE1-1"
+          path_new << trace_new
           last_trace_ssid = current_ssid
         end
       else     
@@ -339,11 +356,15 @@ class DigipeaterPlugin < Plugin
     end
 
     if last_wide_ssid > 0 
-      path_new << "WIDE" + last_wide_ssid.to_s + "-" + last_wide_ssid.to_s
+      wide_new = "WIDE" + last_wide_ssid.to_s + "-" + last_wide_ssid.to_s
+      wide_new = "WIDE2-1" if wide_new == "WIDE1-1"
+      path_new << wide_new
     end
 
     if last_trace_ssid > 0 
-      path_new << "TRACE" + last_trace_ssid.to_s + "-" + last_trace_ssid.to_s
+      trace_new = "TRACE" + last_trace_ssid.to_s + "-" + last_trace_ssid.to_s
+      trace_new = "TRACE2-1" if trace_new == "TRACE1-1"
+      path_new << trace_new
     end
       
 
@@ -369,6 +390,11 @@ class DigipeaterPlugin < Plugin
       return
     end
 
+    if @permittedHops.nil?
+      @@logger.warn( "permittedHops not set")
+      return
+    end
+
     ssid_sum = 0
 
     # search for last repeated flag
@@ -391,7 +417,7 @@ class DigipeaterPlugin < Plugin
     end
 
     @@logger.debug( "ssid_sum: #{ssid_sum}")
-    @@logger.debug( "hops: #{@hops}")
+    @@logger.debug( "permittedHops: #{@permittedHops}")
 
     for i in repeated_index...path.length
       entry = path[i]
@@ -400,11 +426,11 @@ class DigipeaterPlugin < Plugin
       if entry =~ /WIDE[2-9]/ || entry =~ /TRACE[2-9]/
         ssid = call.ssid
 
-        if ssid_sum > @hops
+        if ssid_sum > @permittedHops
 
-          @@logger.debug( "in if: ssid_sum: #{ssid_sum}, hops: #{@hops}")
+          @@logger.debug( "in if: ssid_sum: #{ssid_sum}, permittedHops: #{@permittedHops}")
           
-          decrement = [ ssid_sum - @hops, ssid].min
+          decrement = [ ssid_sum - @permittedHops, ssid].min
 
           call.ssid -= decrement
           ssid_sum -= decrement
