@@ -17,6 +17,7 @@
 #  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 #
 
+require 'aprs4r/ConfigurationAttribute'
 require 'aprs4r/PluginConfiguration'
 
 
@@ -26,7 +27,18 @@ class GatewayPluginConfiguration < PluginConfiguration
   attr_writer :inDevice, :outDevice, :filter
 
   def to_yaml_properties
-    %w{ super @inDevice @outDevice @filter}
+    return super + %w{@inDevice @outDevice @filter}
+  end
+
+  def attributes
+    
+    attributes = [ 
+                  ConfigurationAttribute.new( "inDevice", 11, "text", "Empfangsschnitstelle", 10), 
+                  ConfigurationAttribute.new( "outDevice", 12, "text", "Sendeschnitstelle", 10),
+                  ConfigurationAttribute.new( "filter", 13, "text", "Filter", 10)
+                 ]
+
+    return super + attributes
   end
 
 end
