@@ -26,7 +26,7 @@ class ISServerConfiguration < PluginConfiguration
   attr_writer :port, :device
 
   def to_yaml_properties
-    %w{ super @port @device}
+    return super + %w{@port @device}
   end
 
 end
