@@ -1,6 +1,7 @@
 #
 #  APRS4R - a ruby based aprs gateway/digipeater
-#  Copyright (C) 2006 by Michael Conrad <do5mc@friggleware.de>
+#  Copyright (C) 2007 by Michael Conrad <do5mc@friggleware.de> and
+#                        Andreas Bier <dl1hrc@web.de>
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -49,7 +50,7 @@ class ISSocket
       @type = configuration.type
       @enable = configuration.enable
       
-      @host = configuration.host
+      @hosts = configuration.hosts
       @port = configuration.port
       @username = configuration.username
       @password = ISSocket.generatePassword( @username)
@@ -93,7 +94,11 @@ class ISSocket
     @@logger.info( "initClientISSocket()")
 
     begin 
-      @socket = TCPSocket.new( @host, @port)
+      
+      host = @hosts.first
+
+      @@logger.debug( "connecting to #{host}:#{@port}")
+      @socket = TCPSocket.new( host, @port)
 
       @socket.nonblock = true
       @socket.sync = true 
@@ -110,6 +115,11 @@ class ISSocket
 
       # wait 5 seconds before next try
       sleep 5
+
+      # rotate aprs server list 
+      host = @hosts.delete_at( 0)
+      @hosts << host
+
       retry
     end
 
