@@ -18,15 +18,30 @@
 #
 
 require 'aprs4r/SocketConfiguration'
+require 'aprs4r/ConfigurationAttribute'
+
 
 class ISSocketConfiguration < SocketConfiguration
 
-  attr_reader :host, :port, :username, :filter, :timeout
-  attr_writer :host, :port, :username, :filter, :timeout
+  attr_reader :hosts, :port, :username, :filter, :timeout
+  attr_writer :hosts, :port, :username, :filter, :timeout
 
 
   def to_yaml_properties
-    %w{ super @host @port @username @filter @timeout}
+    super + %w{@hosts @port @username @filter @timeout}
+  end
+
+
+  def attributes
+    attributes = [
+                  ConfigurationAttribute.new( "host", true, 10, "string", "Hostname", 10),
+                  ConfigurationAttribute.new( "port", true, 11, "int", "Portnummer", 6),
+                  ConfigurationAttribute.new( "username", true, 12, "string", "Benutzer", 10),
+                  ConfigurationAttribute.new( "filter", true, 13, "string", "Filter", 20),
+                  ConfigurationAttribute.new( "timeout", true, 15, "int", "Timeout", 6)
+                 ]
+
+    return super + attributes 
   end
 
 end
