@@ -1,6 +1,8 @@
 #
 #  APRS4R - a ruby based aprs gateway/digipeater
-#  Copyright (C) 2006 by Michael Conrad <do5mc@friggleware.de>
+#  Copyright (C) 2007 by Michael Conrad <do5mc@friggleware.de> and
+#                        Andreas Bier <dl1hrc@web.de>
+#                        Christopher A. Kantarjiev <cak@dimebank.com>
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -39,9 +41,14 @@ class KISSDevice
     @@logger.info( "initialize( device, baudrate, call, speed, timeout, mode)")
     
     @device = device
-    @baudrate = baudrate 
     @call = call
-    @speed = speed
+
+    @baudrate = 9600 
+    @baudrate = baudrate if baudrate 
+
+    @speed = 1200 
+    @speed = speed if speed 
+
     @timeout = timeout
     @mode = mode
 
@@ -62,13 +69,7 @@ class KISSDevice
         @port.close
       end
       
-      # default baud rate
-      baudrate = 9600 
-      if @baudrate
-        baudrate = @baudrate
-      end
-
-      @port = SerialPort.new( @device, baudrate, 8, 1, SerialPort::NONE)
+      @port = SerialPort.new( @device, @baudrate, 8, 1, SerialPort::NONE)
       @port.nonblock = true 
       @port.sync = true
       
@@ -78,12 +79,18 @@ class KISSDevice
         initTNC2Northlink
       elsif @mode.index( "tnc2/tapr") != nil
         initTNC2TAPR
+      elsif @mode.index( "tnc2/multi") != nil
+        initTNC2Multi
       elsif @mode.index( "tnc7") != nil
         initTNC7
       elsif @mode.index( "kenwood") != nil
         initKenwood
-      elsif @mode.index( "scs") != nil
-        initSCS
+      elsif @mode.index( "scs/ptc") != nil
+        initSCSPTC
+      elsif @mode.index( "scs/tracker") != nil
+        initSCSTracker
+      elsif @mode.index( "ot2") != nil
+        initOpenTracker2
       else
         initDefault
       end
@@ -168,6 +175,38 @@ class KISSDevice
   end
 
 
+  def initTNC2Multi
+    @@logger.info( "initTNC2Multi")
+    
+    # send exit frame 
+    data = String.new 
+    data << @@FEND
+    data << 0xFF
+    data << @@FEND
+    data << 0x0D.chr
+
+    @@logger.debug( "send KISS exit frame");
+    @port.write( data)
+
+    sleep 2    # WICHTIG, mit sleep 1 ging es nur jedes zweite Mal!!
+      
+    # enable kiss mode
+    @@logger.debug( "send: mycall #{@call}");
+    @port.write( "mycall #{@call}\r")
+    sleep 1
+
+    kiss = String.new
+    kiss << 0x1B
+    kiss << "@K"
+    kiss << 0x0D
+
+    @@logger.debug( "send: kiss on ");
+    @port.write( kiss );
+    sleep 1
+    return
+  end
+  
+
   def initTNC7
     @@logger.info( "initTNC7")
     
@@ -177,8 +216,8 @@ class KISSDevice
   end
 
 
-  def initSCS
-    @@logger.info( "initSCS")
+  def initSCSPTC
+    @@logger.info( "initSCSPTC")
     
     # send exit frame 
     data = String.new
@@ -194,30 +233,50 @@ class KISSDevice
     data = String.new
     data << 0x1B.chr
     @port.write( data)
-
     sleep 1
 
     # enable packet mode
     @@logger.debug( "send PACKET command")
     @port.write( "PACKET\r\n")
-
     sleep 1
 
     @@logger.debug( "send: baud #{@speed}");
     @port.write( "baud #{@speed}\r\n");
-
     sleep 1
 
     # enable kiss mode
     @@logger.debug( "send KISS command")
     @port.write( "KISS\r\n")
-
     sleep 1
 
     return
   end
 
 
+  def initSCSTracker
+    @@logger.info( "initSCSTracker")
+
+    initTNC2Northlink
+
+    return
+  end
+
+
+  def initOpenTracker2
+    @@logger.info( "initOpenTracker2")
+    
+    @@logger.debug( "restart OT2") 
+    @port.write( "\003\003\003\r\003\003\003\r") 
+    sleep 2
+
+    @@logger.debug( "send: AMODE KISS") 
+    @port.write( "AMODE KISS\r") 
+    sleep 2
+
+    return
+  end
+
+
   def initKenwood
     @@logger.info( "initKenwood")
 
@@ -347,14 +406,16 @@ class KISSDevice
 
     data << @@FEND
     data << 0x00
-    # data << 0x7E
     data << encodeKISS( message)
-    # data << 0x00
-    # data << 0x00
-    # data << 0x7E
     data << @@FEND
 
     @mutex.synchronize do
+      
+      # if tnc is an opentracker 2, wait 1/4 second
+      if @mode == "kiss/ot2"
+        sleep 0.250
+      end
+
       @port.puts( data)
     end
 
