@@ -26,7 +26,7 @@ class LCD4LinuxPluginConfiguration < PluginConfiguration
   attr_writer :file, :devices
 
   def to_yaml_properties
-    %w{ super @file @devices}
+    return super + %w{@file @devices}
   end
 
 end
