@@ -26,7 +26,7 @@ class LogPluginConfiguration < PluginConfiguration
   attr_writer :device, :file
 
   def to_yaml_properties
-    %w{ super @device @file}
+    return super + %w{@device @file}
   end
 
 end
