@@ -26,7 +26,7 @@ class MessagePluginConfiguration < PluginConfiguration
   attr_writer :rfDevice, :isDevice, :timeout
 
   def to_yaml_properties
-    %w{ super @rfDevice @isDevice @timeout}
+    return super + %w{@rfDevice @isDevice @timeout}
   end
 
 end
