@@ -26,7 +26,20 @@ class PluginConfiguration
 
 
   def to_yaml_properties
-    %w{ @name @type @enable}
+    return %w{ @name @type @enable}
+  end
+
+
+  def attributes
+
+    pluginSelection = [ "BeaconPlugin"]
+    attributes = [ 
+                  ConfigurationAttribute.new( "name", 01, "text", "Name", 10), 
+                  ConfigurationAttribute.new( "type", 02, "select", "Typ", 10, pluginSelection),
+                  ConfigurationAttribute.new( "enable", 03, "boolean", "aktiviert", 0),
+                 ]
+
+    return attributes
   end
 
 end
