@@ -26,7 +26,7 @@ class QueryPluginConfiguration < PluginConfiguration
   attr_writer :device, :call
 
   def to_yaml_properties
-    %w{ super @device @call}
+    return super + %w{@device @call}
   end
 
 end
