@@ -17,6 +17,9 @@
 #  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 #
 
+require 'aprs4r/ConfigurationAttribute'
+
+
 class SocketConfiguration
 
   attr_reader :name, :type, :enable, :duplicatePeriod
@@ -24,6 +27,24 @@ class SocketConfiguration
 
 
   def to_yaml_properties
-    %w{ @name @type @enable @duplicatePeriod}
+    return %w{@name @type @enable @duplicatePeriod}
   end
+
+
+  def attributes
+
+    attributes = [ 
+                  ConfigurationAttribute.new( "name", true, 01, "text", "Name", 10), 
+                  ConfigurationAttribute.new( "type", false, 02, "text", "Typ", 10),
+                  ConfigurationAttribute.new( "enable", true, 03, "boolean", "aktiviert", 0),
+                  ConfigurationAttribute.new( "duplicatePeriod", true, 04, "int", "Duplikat", 10)
+                 ]
+
+    return attributes
+  end
+
+  def SocketConfiguration.subclasses
+    return [ "AX25Socket", "ISSocket"]
+  end
+
 end
