@@ -22,14 +22,18 @@ require 'Logger'
 # require 'aprs4r/AX25Socket'
 # require 'aprs4r/ISSocket'
 # require 'aprs4r/RawSocket'
-require 'aprs4r/SocketThread'
+
+require 'aprs4r/SocketRecvThread'
+require 'aprs4r/SocketSendThread'
 
 
 class SocketManager
 
   @@singleton = nil
 
-  @@threads = Array.new
+  @@recvThreads = Hash.new
+  @@sendThreads = Hash.new
+
   @@sockets = Hash.new
   @@listeners = Hash.new
   @@duplicates = Hash.new
@@ -74,14 +78,29 @@ class SocketManager
           
         rescue LoadError
           @@logger.warn( "unable to load socket #{type}")
+          socket = nil
         end
 
         if socket 
           @@logger.debug( "socket: #{socket}")
         
-          @@threads << Thread.new { 
-            thread = SocketThread.new( socket)
-            thread.run
+          # start recv thread
+          recvThread = SocketRecvThread.new( socket)
+          @@recvThreads[name] = recvThread
+
+          Thread.new { 
+            recvThread.run
+          }
+
+          # start send thread
+          sendThread = SocketSendThread.new( socket)
+          @@sendThreads[name] = sendThread
+          Thread.new { 
+            sendThread.run
+          }
+
+          Thread.new { 
+            run( name)
           }
         
           @@sockets[name] = socket
@@ -97,6 +116,20 @@ class SocketManager
     return
   end
 
+
+  def SocketManager.run( name)
+    @@logger.info( "run( name)")
+
+    recvThread = @@recvThreads[name]
+
+    while true 
+      message = recvThread.recvAPRSMessage
+
+      SocketManager.recvAPRSMessage( name, message)
+    end
+
+  end
+
   
   def SocketManager.addListener( name, listener)
     @@logger.info( "addListener( name, listener)")
@@ -122,8 +155,8 @@ class SocketManager
   end
 
   
-  def SocketManager.receiveAPRSMessage( name, message)
-    @@logger.info( "receiveAPRSMessage( name, message)")
+  def SocketManager.recvAPRSMessage( name, message)
+    @@logger.info( "recvAPRSMessage( name, message)")
 
     if message.nil?
       return
@@ -134,8 +167,6 @@ class SocketManager
       return
     end
 
-    @@logger.warn( "message recv on #{name}: #{message}")
-
     @@recvCount[name] += 1
     @@lastMessage = message
 
@@ -155,23 +186,22 @@ class SocketManager
   def SocketManager.sendAPRSMessage( name, message)
     @@logger.info( "sendAPRSMessage( name, message)")
     
-    socket = @@sockets[name]
+    sendThread = @@sendThreads[name]
 
-    if message.nil? || socket.nil?
-      @@logger.warn( "message || socket: nil\n")
+    if message.nil? || sendThread.nil?
+      @@logger.warn( "message || thread: nil\n")
       return
     end
 
     if SocketManager.duplicate?( name, message)
-      @@logger.warn( "send: duplicate message dropped")
+      @@logger.warn( "send: duplicate message: #{message.source}")
       return
     end
 
     @@sendCount[name] += 1
 
-    # write message
-    @@logger.warn( "message send on #{name}: #{message}")
-    socket.writeAPRSMessage( message)
+    # send message and wakeup waiting thread
+    sendThread.sendAPRSMessage( name, message)
 
     SocketManager.addDuplicate( name, message)
 
