@@ -27,7 +27,7 @@ class WMRWeatherConfiguration < WeatherConfiguration
 
 
   def to_yaml_properties
-    %w{ super @file}
+    return super + %w{@file}
   end
 
 end
