@@ -40,7 +40,6 @@ class WMRWeatherPlugin < WeatherPlugin
 
     @file = configuration.file
 
-    # @port = File.new( @file, "r")
     @port = SerialPort.new( @file, 9600, 8, 1, SerialPort::NONE)
     @port.nonblock = true 
     @port.sync = true
@@ -55,6 +54,7 @@ class WMRWeatherPlugin < WeatherPlugin
     @temperature = nil
     @humidity = nil
     @dewpoint = nil
+    @pressure = nil
 
     Thread.new{ runWMRThread }
 
@@ -146,7 +146,7 @@ class WMRWeatherPlugin < WeatherPlugin
         @rain_yesterday = record.rain_yesterday
       end
       
-      if record.has_thermo?
+      if record.has_thermo_outdoor?
         @@logger.info( "thermo: temperature: #{record.temperature}, humidity: #{record.humidity}, dewpoint: #{record.dewpoint}")
         @temperature = record.temperature
         @humidity = record.humidity
