@@ -28,7 +28,7 @@ class WSconWeatherConfiguration < WeatherConfiguration
 
 
   def to_yaml_properties
-    %w{ super @device @message}
+    return super + %w{@device @message}
   end
 
 end
