@@ -28,7 +28,7 @@ class WeatherConfiguration < PluginConfiguration
 
 
   def to_yaml_properties
-    %w{ super @device @period @offset @message}
+    return super + %w{@device @period @offset @message}
   end
 
 end
